@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: Minimal-configuration, read-only LDAP server
 
-our $VERSION = '0.0.20';    # VERSION
+our $VERSION = '0.0.21';    # VERSION
 
 use 5.008;
 use Carp;
@@ -20,10 +20,6 @@ sub import {
     croak $@ if $@;
 
     push @Net::LDAP::SimpleServer::ISA, qw(Net::Server);
-
-    #use Data::Dumper;
-    #print STDERR Data::Dumper->Dump( [ \@Net::LDAP::SimpleServer::ISA ],
-    #    ['ISA'] );
     return;
 }
 
@@ -140,7 +136,7 @@ Net::LDAP::SimpleServer - Minimal-configuration, read-only LDAP server
 
 =head1 VERSION
 
-version 0.0.20
+version 0.0.21
 
 =head1 SYNOPSIS
 
@@ -177,9 +173,8 @@ prototyping and/or development purposes. This is B<NOT> intended to be a
 production-grade server, although some brave souls in small offices might
 use it as such.
 
-As of April 2010, the server will load a LDIF file and serve its
-contents through the LDAP protocol. Many operations are B<NOT> available yet,
-notably writing into the directory tree.
+The server will load a LDIF file and serve its contents through the LDAP
+protocol. Many operations are B<NOT> available yet, some will never be.
 
 The constructors will follow the rules defined by L<Net::Server>, but the most
 useful are the two forms described below.
@@ -210,8 +205,9 @@ reference.
 
 =head2 options()
 
-As specified in L<Net::Server>, this method creates new options for the,
-server, namely:
+As specified in L<Net::Server>, this method creates new options for the
+server. Hence, in addition to L<Net::Server> options, this module also
+allows setting the following parameters:
 
 =over 4
 
@@ -231,6 +227,22 @@ root_pw - the password for root_dn
 
 allow_anon - whether to allow for anonymous binds
 
+=item *
+
+user_filter - LDAP filter to find user entries
+
+=item *
+
+user_id_attr - attribute of a LDAP entry that contains the username
+
+=item *
+
+user_pw_attr - attribute of a LDAP entry that contains the password
+
+=item *
+
+user_passwords - whether to return password values in searches
+
 =back
 
 =head2 default_values()
@@ -240,7 +252,7 @@ number of options.
 
 Notice that we do set a default password for the C<< cn=root >> DN. This
 allows for out-of-the-box testing, but make sure you change the password
-when putting this to production use.
+when putting this to use.
 
 =head2 post_configure_hook()
 
@@ -271,11 +283,19 @@ We plan to implement more options in Net::LDAP::SimpleServer. Some ideas are:
 
     #objectclass_req (true|false)
     #user_tree dc=some,dc=subtree,dc=com
-    #user_id_attr uid
-    #user_pw_attr password
 
 Keeping in mind we do NOT want to implement a full blown LDAP server.
 
+=head1 Contributors in CPAN RT
+
+=over 4
+
+=item *
+
+Ian Puleston <ipuleston@SonicWALL.com>
+
+=back
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
